' File: FemapPicToPPT.BAS
' Version: Version 01
' Date: February 23, 2015
' Author: Ben Mann, ATA Engineering
' www.ata-plmsoftware.com
' Description: This API links with PowerPoint to create a presentation of sensor locations and orientations in your model. 
'              It highlights each coordinate system the user selects individually and adds the picture to a new slide.
'
'Usage Notes
'====================================
' This API highlights coordinate systems that define directions of a accelerometer. Images are taken of each CS
' and placed on different slides. The view of the model in Femap does not change.
'
'Copyright (c) <2015> <ATA Engineering, Inc.>
'
'Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
'associated documentation files (the "Software") to use, copy, modify, merge, and/or distribute
'royalty-free copies of the Software, and to permit persons to whom the Software is furnished
'to do so, subject to the following conditions:
'The above copyright notice and this permission notice shall be included in all copies or
'substantial portions of the Software.
'THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
'INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
'FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
'IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
'WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
'OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.       
'
Sub Main
    Dim App As femap.model
    Set App = feFemap()

    Dim fName As String
    Dim AppPP As Object
    Dim PP1 As Object
    Dim PPSlide As Object
    Dim ids As Set
    Dim view1 As View
    Dim cs1 As Set
    Dim offset As Long

    Set view1 = App.feView
    Set ids = App.feSet
    Set cs1 = App.feSet

    view1.First()

    'New or Existing PPT
	Begin Dialog UserDialog 300,140,"PowerPoint Selection" ' %GRID:10,7,1,1
		OptionGroup .Group1
			OptionButton 90,49,90,14,"New",.OptionButton1
			OptionButton 90,77,90,14,"Existing",.OptionButton2
		text 40,7,210,28,"Do you want to add pictures to a new or existing PPT?",.Text1,2
		OKButton 200,112,90,21
		CancelButton 100,112,90,21
	End Dialog

	Dim dlg As UserDialog
	result = Dialog(dlg)

	If result = 0 Then
		Exit Sub
	End If

	If dlg.group1 = 0 Then
		'Create New PPT
		Set AppPP = CreateObject("Powerpoint.Application")
		Set PP1 = AppPP.Presentations.Add

		offset = 1
	Else
	    'Get name of PPT File
	    rc = App.feFileGetName("Open Powerpoint File","PPT Files","*.ppt*",True,fName)
	    If rc = 0 Then
	        Exit Sub
	    End If
	    'Connect to Existing powerpoint and open presentation
	    Set AppPP = CreateObject("Powerpoint.Application")
	    Set PP1 = AppPP.Presentations.Open(fName)

	    'Get slide to start pictures on
	    rc = App.feGetInt("Specify Slide Number to Start Adding Pictures",1,10000,offset)
	    If rc = 2 Then
	        Exit Sub
	    End If
    End If

    cont=0
    While cont = 0
		Begin Dialog UserDialog1 510,231 ' %GRID:10,7,1,1
			GroupBox 30,7,440,154,"Select Picture Location",.GroupBox1
			OptionGroup .Group1
				OptionButton 50,35,100,14,"NorthWest",.OptionButton1
				OptionButton 200,35,90,14,"North",.OptionButton2
				OptionButton 360,35,90,14,"NorthEast",.OptionButton3
				OptionButton 360,84,90,14,"East",.OptionButton4
				OptionButton 360,133,90,14,"SouthEast",.OptionButton5
				OptionButton 200,133,90,14,"South",.OptionButton6
				OptionButton 50,133,100,14,"SouthWest",.OptionButton7
				OptionButton 50,84,90,14,"West",.OptionButton8
				OptionButton 200,84,90,14,"Center",.OptionButton9
			OKButton 410,203,90,21
			CancelButton 300,203,90,21
			TextBox 200,168,90,21,.w1
			text 10,172,180,14,"Specify Picture Width (in.):",.Text1,1
		End Dialog
		Dim dlg1 As UserDialog1

		Result = Dialog(dlg1)

		If result = 0 Then
			Exit Sub
		End If
		If dlg1.w1 = "" Then
			App.feAppMessageBox(1,"Please specify picture width.")
		Else
			width = CDbl(dlg1.w1)
			cont=1
		End If
	Wend



    'Bring in list of CSYS IDs
    rc = ids.Select(FT_CSYS,True,"Select IDs of Sensor Coordinate Systems in Order")
    If rc = 2 Then
        Exit Sub
    End If

    ' Get original label parameters
    lp_0 = view1.Label(FVI_LABEL)

    ' Make Labels Large to Read
    view1.Label(FVI_LABEL) = 6
    view1.Redraw()
    view1.Put(view1.ID)

    For n=1 To ids.Count
        cs1.Clear
        If n = 1 Then
            cs1.Add(ids.First)
        Else
            cs1.Add(ids.Next)
        End If

        App.feViewShow(FT_CSYS,cs1.ID)
        App.feFilePictureCopy2(FPRG_WINDOW)

        slide_num = n+offset-1
        slide_count = PP1.Slides.Count

        If slide_count < slide_num Then
        	slides_needed = slide_num-slide_count
        	For k = 1 To slides_needed
        		ind = slide_count+k
        		Set PPSlide = PP1.Slides.Add(ind,Layout:=12)
        	Next
        End If


        Set pic1 = PP1.Slides(slide_num).Shapes.Paste

        ratio = pic1.Height/pic1.Width


        ppt_ratio = 72.046 'PPT Sizing Ratio to Inches
        With pic1
            .LockAspectRatio = msoTrue
            .Width = ppt_ratio*width
            .Height = ratio*pic1.Width
            Select Case dlg1.Group1
            Case 0 'NW
            	.Left =.1*ppt_ratio
           		.Top = .1*ppt_ratio
            Case 1 'N
            	.Left = 5*ppt_ratio-pic1.Width/2
            	.Top = .1*ppt_ratio
            Case 2 'NE
            	.Left = 10*ppt_ratio-pic1.Width-.1*ppt_ratio
            	.Top = .1*ppt_ratio
            Case 3 'E
            	.Left = 10*ppt_ratio-pic1.Width-.1*ppt_ratio
            	.Top = 3.75*ppt_ratio-pic1.Height/2
            Case 4 'SE
            	.Left = 10*ppt_ratio-pic1.Width-.1*ppt_ratio
            	.Top = 7.5*ppt_ratio-pic1.Height-.1*ppt_ratio
            Case 5 'S
            	.Left = 5*ppt_ratio-pic1.Width/2
            	.Top = 7.5*ppt_ratio-pic1.Height-.1*ppt_ratio
            Case 6 'SW
            	.Left =.1*ppt_ratio
            	.Top = 7.5*ppt_ratio-pic1.Height-.1*ppt_ratio
            Case 7 'W
            	.Left =.1*ppt_ratio
            	.Top = 3.75*ppt_ratio-pic1.Height/2
            Case 8 'Center
            	.Left = 5*ppt_ratio-pic1.Width/2
            	.Top = 3.75*ppt_ratio-pic1.Height/2
            End Select
        End With
    Next

    ' Reset to original label parameters
    view1.Label(FVI_LABEL) = lp_0
    view1.Redraw()
    view1.Put(view1.ID)

End Sub
